segmag
object under the null hypothesis that all key presses were randomly
distributed (uniformly) across the experiment (time_min to time_max).
bootstrap_critical_cutoffs(segmag, n_bootstrap, critical_probs, segmag_substract = NULL, visualize = FALSE, save_as = NULL)segmagsegmag. If this value is set
than keypress times in segmag and segmag_substract are
both randomized and the critical_cutoffs relate to
the difference of the segmentation magnitude in segmag
minus the segmentation magnitude in segmag_substractThe function returns the critical_probs quantiles of the vector of those
largest maxima obtained across n_bootstap iterations
This function can also be used to bootstrap the critical maxima and minima cutoffs of a difference function of two segmag objects. To do so, segmag and segmag_substract must be defined. All values will be related to the difference of segmag - segmag_substract (Keypress times in segmag and segmag_substract are randomized independently).
get_eb_times, segmag