Learn R Programming

segmag (version 1.2.4)

get_eb_times: Retrieve event boundary times from a segmag object

Description

Returns the times of event boundaries from a segmag object. Event boundaries are defined as the center of local maxima in segmentation magnitude that are higher than a critical cutoff value. The critical cutoff value should be determined with the bootstrap_critical_cutoffs function.

Usage

get_eb_times(segmag, cutoff)

Arguments

segmag
object of class segmag
cutoff
numeric value determining the critical cutoff in segmentation magnitude

Value

numeric vector with event boundary times

See Also

get_eb_times_segmag_diff, bootstrap_critical_cutoffs

Examples

Run this code
#see ?segmag for an example

Run the code above in your browser using DataLab