Learn R Programming

segmag (version 1.2.4)

get_eb_times_segmag_diff: Retrieve event boundary times for a difference of segmag objects

Description

Specific function when calculating event boundaries for the difference of two segmag objects (segmag - segmag_substract). Returns the times of event boundaries that are defined as the center of local maxima (minima) in segmentation magnitude that are higher (lower) than a critical cutoff max/min values. The critical cutoff max/min values should be determined with the bootstrap_critical_cutoffs function.

Usage

get_eb_times_segmag_diff(segmag, segmag_substract, cutoff_max = NULL, cutoff_min = NULL)

Arguments

segmag
object of class segmag
segmag_substract
object of class segmag.
cutoff_max
numeric value determining the critical cutoff for maxima in segmentation magnitude
cutoff_min
numeric value determining the critical cutoff for minima in segmentation magnitude

Value

numeric vector with event boundary times. If cutoff_max or cutoff_min is NULL than the respective event boundaries are omitted.

See Also

get_eb_times, bootstrap_critical_cutoffs