get_eb_times: Retrieve event boundary times from a segmag object
Description
Returns the times of event boundaries from a segmag object. Event boundaries
are defined as the center of local maxima in segmentation magnitude that are
higher than a critical cutoff value. The critical cutoff value should be
determined with the bootstrap_critical_cutoffs function.