get_eb_times_segmag_diff: Retrieve event boundary times for a difference of segmag objects
Description
Specific function when calculating event boundaries for the difference of
two segmag objects (segmag - segmag_substract). Returns the times of event
boundaries that are defined as the center of local maxima (minima) in
segmentation magnitude that are higher (lower) than a critical cutoff max/min values.
The critical cutoff max/min values should be determined with the
bootstrap_critical_cutoffs function.